# AUTOGENERATED! DO NOT EDIT! File to edit: dev/00_core.ipynb (unless otherwise specified).

__all__ = ['med_csv', 'med_show']

# Cell
def med_csv():
    print("TODO")

# Cell
def med_show(df,num_to_show=5,transpose=True):
    #df.head(2).T
    print(f'{num_to_show}_TODO')