# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"med_csv": "00_core.ipynb",
         "med_show": "00_core.ipynb"}

modules = ["core.py"]

git_url = "https://github.com/Daniel-R_Armstrong/med2nlp/tree/master/"


def custom_doc_links(name): return None
